psychopy_ext.exp.Experiment.before_exp — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Experiment.before_exp

`Experiment.` `before_exp`(text=None, wait=0.5, wait_stim=None, **kwargs)

  Instructions at the beginning of the experiment.

  Kwargs: | text (str, default: None) Text to show. wait (float, default: .5) How long to wait after the end of showing instructions, in seconds. wait_stim (stimulus or a list of stimuli, default: None) During this waiting, which stimuli should be shown. Usually, it would be a fixation spot. **kwargs Other parameters for `show_text()`